Builder
=======

.. currentmodule:: toasty.builder

.. autoclass:: Builder
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Builder.imgset
      ~Builder.pio
      ~Builder.place

   .. rubric:: Methods Summary

   .. autosummary::

      ~Builder.apply_avm_info
      ~Builder.apply_wcs_info
      ~Builder.cascade
      ~Builder.create_wtml_folder
      ~Builder.default_tiled_study_astrometry
      ~Builder.execute_study_tiling
      ~Builder.load_from_wwtl
      ~Builder.make_placeholder_thumbnail
      ~Builder.make_thumbnail_from_other
      ~Builder.prepare_study_tiling
      ~Builder.set_name
      ~Builder.tile_base_as_study
      ~Builder.toast_base
      ~Builder.write_index_rel_wtml

   .. rubric:: Attributes Documentation

   .. autoattribute:: imgset
   .. autoattribute:: pio
   .. autoattribute:: place

   .. rubric:: Methods Documentation

   .. automethod:: apply_avm_info
   .. automethod:: apply_wcs_info
   .. automethod:: cascade
   .. automethod:: create_wtml_folder
   .. automethod:: default_tiled_study_astrometry
   .. automethod:: execute_study_tiling
   .. automethod:: load_from_wwtl
   .. automethod:: make_placeholder_thumbnail
   .. automethod:: make_thumbnail_from_other
   .. automethod:: prepare_study_tiling
   .. automethod:: set_name
   .. automethod:: tile_base_as_study
   .. automethod:: toast_base
   .. automethod:: write_index_rel_wtml
